@@ -17,6 +17,7 @@
 #include <QGpgME/DecryptJob>
 #include <QGpgME/DecryptVerifyJob>
 
+#include <Libkleo/Compliance>
 #include <Libkleo/Dn>
 #include <Libkleo/KleoException>
 #include <Libkleo/Stl_Util>
@@ -259,7 +260,7 @@ static QString formatSigningInformation(const Signature &sig)
     if (sig.isNull()) {
         return QString();
     }
-    const QDateTime dt = sig.creationTime() != 0 ? QDateTime::fromSecsSinceEpoch(sig.creationTime()) : QDateTime();
+    const QDateTime dt = sig.creationTime() != 0 ? QDateTime::fromSecsSinceEpoch(quint32(sig.creationTime())) : QDateTime();
     QString text;
     Key key = sig.key();
     if (dt.isValid()) {
@@ -270,14 +271,14 @@ static QString formatSigningInformation(const Signature &sig)
     }
     text += i18n("With certificate:") + QStringLiteral("<br>") + renderKey(key);
 
-    if (Kleo::gnupgIsDeVsCompliant()) {
+    if (DeVSCompliance::isCompliant()) {
         text +=
             (QStringLiteral("<br/>")
              + (sig.isDeVs()
                 ? i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
-                        "The signature is %1", Formatting::deVsString())
+                        "The signature is %1", DeVSCompliance::name(true))
                 : i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
-                        "The signature <b>is not</b> %1.", Formatting::deVsString())));
+                        "The signature <b>is not</b> %1.", DeVSCompliance::name(true))));
     }
 
     return text;
@@ -574,12 +575,12 @@ static QString formatDecryptionResultDetails(const DecryptionResult &res, const
 
     QString details;
 
-    if (Kleo::gnupgIsDeVsCompliant()) {
+    if (DeVSCompliance::isCompliant()) {
         details += ((res.isDeVs()
                      ? i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
-                             "The decryption is %1.", Formatting::deVsString())
+                             "The decryption is %1.", DeVSCompliance::name(true))
                      : i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
-                             "The decryption <b>is not</b> %1.", Formatting::deVsString()))
+                             "The decryption <b>is not</b> %1.", DeVSCompliance::name(true)))
                     + QStringLiteral("<br/>"));
     }
 
@@ -648,7 +649,7 @@ public:
             const DecryptionResult &dr,
             const QByteArray &stuff,
             const QString &fileName,
-            int errCode,
+            const GpgME::Error &error,
             const QString &errString,
             const QString &input,
             const QString &output,
@@ -662,7 +663,7 @@ public:
         m_decryptionResult(dr),
         m_stuff(stuff),
         m_fileName(fileName),
-        m_error(errCode),
+        m_error(error),
         m_errorString(errString),
         m_inputLabel(input),
         m_outputLabel(output),
@@ -696,7 +697,7 @@ public:
     DecryptionResult m_decryptionResult;
     QByteArray m_stuff;
     QString m_fileName;
-    int m_error;
+    GpgME::Error m_error;
     QString m_errorString;
     QString m_inputLabel;
     QString m_outputLabel;
@@ -718,7 +719,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResul
             dr,
             plaintext,
             {},
-            0,
+            {},
             QString(),
             inputLabel(),
             outputLabel(),
@@ -735,7 +736,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResul
             DecryptionResult(err),
             QByteArray(),
             {},
-            err.code(),
+            err,
             what,
             inputLabel(),
             outputLabel(),
@@ -746,7 +747,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResul
 
 std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResult(const DecryptionResult &dr, const VerificationResult &vr, const QByteArray &plaintext, const QString &fileName, const AuditLog &auditLog)
 {
-    int err = dr.error() ? dr.error().code() : vr.error().code();
+    const auto err = dr.error().code() ? dr.error() : vr.error();
     return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             DecryptVerify,
             vr,
@@ -770,7 +771,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerif
             DecryptionResult(err),
             QByteArray(),
             {},
-            err.code(),
+            err,
             details,
             inputLabel(),
             outputLabel(),
@@ -787,7 +788,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaque
             DecryptionResult(),
             plaintext,
             {},
-            0,
+            {},
             QString(),
             inputLabel(),
             outputLabel(),
@@ -803,7 +804,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaque
             DecryptionResult(),
             QByteArray(),
             {},
-            err.code(),
+            err,
             details,
             inputLabel(),
             outputLabel(),
@@ -820,7 +821,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetach
             DecryptionResult(),
             QByteArray(),
             {},
-            0,
+            {},
             QString(),
             inputLabel(),
             outputLabel(),
@@ -836,7 +837,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetach
             DecryptionResult(),
             QByteArray(),
             {},
-            err.code(),
+            err,
             details,
             inputLabel(),
             outputLabel(),
@@ -850,14 +851,14 @@ DecryptVerifyResult::DecryptVerifyResult(DecryptVerifyOperation type,
         const DecryptionResult &dr,
         const QByteArray &stuff,
         const QString &fileName,
-        int errCode,
+        const GpgME::Error &error,
         const QString &errString,
         const QString &inputLabel,
         const QString &outputLabel,
         const AuditLog &auditLog,
         Task *parentTask,
         const Mailbox &informativeSender)
-    : Task::Result(), d(new Private(type, vr, dr, stuff, fileName, errCode, errString, inputLabel, outputLabel, auditLog, parentTask, informativeSender, this))
+    : Task::Result(), d(new Private(type, vr, dr, stuff, fileName, error, errString, inputLabel, outputLabel, auditLog, parentTask, informativeSender, this))
 {
 }
 
@@ -894,12 +895,7 @@ QString DecryptVerifyResult::details() const
                                             d->m_parentTask);
 }
 
-bool DecryptVerifyResult::hasError() const
-{
-    return d->m_error != 0;
-}
-
-int DecryptVerifyResult::errorCode() const
+GpgME::Error DecryptVerifyResult::error() const
 {
     return d->m_error;
 }
