@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_SIGNENCRYPTTASK_H__
-#define __KLEOPATRA_CRYPTO_SIGNENCRYPTTASK_H__
+#pragma once
 
 #include <crypto/task.h>
 
@@ -81,5 +80,4 @@ private:
 }
 }
 
-#endif /* __KLEOPATRA_CRYPTO_SIGNENCRYPTTASK_H__ */
 
