@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_LOG_H__
-#define __KLEOPATRA_LOG_H__
+#pragma once
 
 #include <utils/pimpl_ptr.h>
 
@@ -61,4 +60,3 @@ private:
 
 }
 
-#endif // __KLEOPATRA_LOG_H__
